@@ -16,12 +16,7 @@ class Cone:
                 kwargs[i] = current_input = [[]]
             elif type(current_input) == bool and current_input == False:
                 kwargs.pop(i)
-
-        for i in kwargs:
-            input_list.append(i)
-            input_list.append(kwargs[i])
-
-        self.cone = PyNormaliz_cpp.NmzCone(input_list)
+        self.cone = PyNormaliz_cpp.NmzCone(input_list,**kwargs)
 
     def __process_keyword_args(self, keywords):
         input_list = []
@@ -61,6 +56,21 @@ class Cone:
         return_cone.cone = new_inner_cone
         return return_cone
 
+    def ProjectCone(self, **kwargs):
+        input_list = self.__process_keyword_args(kwargs)
+        input_list.append("ProjectCone")
+        PyNormaliz_cpp.NmzCompute(self.cone, input_list)
+        new_inner_cone = PyNormaliz_cpp.NmzResult(self.cone, "ProjectCone")
+        return_cone = Cone.__new__(Cone)
+        return_cone.cone = new_inner_cone
+        return return_cone
+
+    def EuclideanVolume(self, **kwargs):
+        input_list = self.__process_keyword_args(kwargs)
+        input_list.append("Volume")
+        PyNormaliz_cpp.NmzCompute(self.cone, input_list)
+        return PyNormaliz_cpp.NmzGetEuclideanVolume(self.cone)
+
     def HilbertSeries(self, **kwargs):
         try:
             as_hsop = kwargs["HSOP"]
@@ -75,6 +85,20 @@ class Cone:
             return PyNormaliz_cpp.NmzHilbertSeries(self.cone, as_hsop)
         raise TypeError("If HSOP is given, it must be True or False")
 
+    def EhrhartSeries(self, **kwargs):
+        try:
+            as_hsop = kwargs["HSOP"]
+        except KeyError:
+            as_hsop = 28
+        input_list = self.__process_keyword_args(kwargs)
+        input_list.append("EhrhartSeries")
+        PyNormaliz_cpp.NmzCompute(self.cone, input_list)
+        if as_hsop == 28:
+            return PyNormaliz_cpp.NmzHilbertSeries(self.cone)
+        if type(as_hsop) == bool:
+            return PyNormaliz_cpp.NmzHilbertSeries(self.cone, as_hsop)
+        raise TypeError("If HSOP is given, it must be True or False")
+
     def Polynomial(self, **kwargs):
         return PyNormaliz_cpp.NmzGetPolynomial(self.cone)
 
@@ -89,6 +113,12 @@ class Cone:
         return_cone.cone = new_inner_cone
         return return_cone
 
+    def HilbertSeriesExpansion(self,degree):
+        return NmzGetHilbertSeriesExpansion(self.cone,degree)
+
+    def WeightedEhrhartSeriesExpansion(self,degree):
+        return NmzGetWeightedEhrhartSeriesExpansion(self.cone,degree)
+
     def PrettyPolynomialTuple(self, numCoefficients, denCoefficients):
         """
         Strings for numerator and denominator of the a hilbert series.
@@ -466,6 +496,12 @@ class Cone:
         PyNormaliz_cpp.NmzCompute(self.cone, input_list)
         return PyNormaliz_cpp.NmzResult(self.cone, "HilbertQuasiPolynomial")
 
+    def EhrhartQuasiPolynomial(self, **kwargs):
+        input_list = self.__process_keyword_args(kwargs)
+        input_list.append("HilbertQuasiPolynomial")
+        PyNormaliz_cpp.NmzCompute(self.cone, input_list)
+        return PyNormaliz_cpp.NmzResult(self.cone, "HilbertQuasiPolynomial")
+
     def IsTriangulationNested(self, **kwargs):
         input_list = self.__process_keyword_args(kwargs)
         input_list.append("IsTriangulationNested")
@@ -519,3 +555,15 @@ class Cone:
         input_list.append("VerticesFloat")
         PyNormaliz_cpp.NmzCompute(self.cone, input_list)
         return PyNormaliz_cpp.NmzResult(self.cone, "VerticesFloat")
+
+    def Volume(self, **kwargs):
+        input_list = self.__process_keyword_args(kwargs)
+        input_list.append("Volume")
+        PyNormaliz_cpp.NmzCompute(self.cone, input_list)
+        return PyNormaliz_cpp.NmzResult(self.cone, "Volume")
+
+    def SuppHypsFloat(self, **kwargs):
+        input_list = self.__process_keyword_args(kwargs)
+        input_list.append("SuppHypsFloat")
+        PyNormaliz_cpp.NmzCompute(self.cone, input_list)
+        return PyNormaliz_cpp.NmzResult(self.cone, "SuppHypsFloat")
